@@ -6,9 +6,12 @@
 #include <errno.h>
 #include <signal.h>
 #include <inttypes.h>
-#include <evhtp.h>
 #include <event2/event.h>
 
+#include "../evhtp-internal.h"
+#include "../evhtp.h"
+
+
 #ifndef EVHTP_DISABLE_EVTHR
 int      use_threads    = 0;
 int      num_threads    = 0;
@@ -21,6 +24,7 @@ char   * ssl_ca         = NULL;
 char   * ssl_capath     = NULL;
 size_t   bw_limit       = 0;
 uint64_t max_keepalives = 0;
+int      backlog        = 1024;
 
 struct pauser {
     event_t         * timer_ev;
@@ -106,7 +110,6 @@ test_pause_cb(evhtp_request_t * request, void * arg) {
     evhtp_send_reply(request, EVHTP_RES_OK);
 }
 
-#ifndef EVHTP_DISABLE_REGEX
 static void
 _owned_readcb(evbev_t * bev, void * arg) {
     /* echo the input back to the client */
@@ -129,6 +132,7 @@ test_ownership(evhtp_request_t * request, void * arg) {
                       _owned_eventcb, NULL);
 }
 
+#ifndef EVHTP_DISABLE_REGEX
 static void
 test_regex(evhtp_request_t * req, void * arg) {
     evbuffer_add_printf(req->buffer_out,
@@ -139,8 +143,6 @@ test_regex(evhtp_request_t * req, void * arg) {
     evhtp_send_reply(req, EVHTP_RES_OK);
 }
 
-#endif
-
 static void
 dynamic_cb(evhtp_request_t * r, void * arg) {
     const char * name = arg;
@@ -170,6 +172,8 @@ create_callback(evhtp_request_t * r, void * arg) {
     evhtp_send_reply(r, EVHTP_RES_OK);
 }
 
+#endif
+
 static void
 test_foo_cb(evhtp_request_t * req, void * arg ) {
     evbuffer_add_reference(req->buffer_out,
@@ -294,7 +298,7 @@ print_data(evhtp_request_t * req, evbuf_t * buf, void * arg) {
     evbuffer_add_printf(req->buffer_out,
                         "got %zu bytes of data\n",
                         evbuffer_get_length(buf));
-    //printf("%.*s", (int)evbuffer_get_length(buf), (char *)evbuffer_pullup(buf, evbuffer_get_length(buf)));
+    /* printf("%.*s", (int)evbuffer_get_length(buf), (char *)evbuffer_pullup(buf, evbuffer_get_length(buf))); */
 #endif
     evbuffer_drain(buf, -1);
     return EVHTP_RES_OK;
@@ -409,7 +413,7 @@ dummy_check_issued_cb(X509_STORE_CTX * ctx, X509 * x, X509 * issuer) {
 
 #endif
 
-const char * optstr = "htn:a:p:r:s:c:C:l:N:m:";
+const char * optstr = "htn:a:p:r:s:c:C:l:N:m:b:";
 
 const char * help   =
     "Options: \n"
@@ -478,6 +482,9 @@ parse_args(int argc, char ** argv) {
             case 'm':
                 max_keepalives = atoll(optarg);
                 break;
+            case 'b':
+                backlog        = atoll(optarg);
+                break;
             default:
                 printf("Unknown opt %s\n", optarg);
                 return -1;
@@ -508,9 +515,14 @@ main(int argc, char ** argv) {
     evhtp_callback_t * cb_3   = NULL;
     evhtp_callback_t * cb_4   = NULL;
     evhtp_callback_t * cb_5   = NULL;
+
+#ifndef EVHTP_DISABLE_REGEX
     evhtp_callback_t * cb_6   = NULL;
+#endif
     evhtp_callback_t * cb_7   = NULL;
+#ifndef EVHTP_DISABLE_REGEX
     evhtp_callback_t * cb_8   = NULL;
+#endif
     evhtp_callback_t * cb_9   = NULL;
     evhtp_callback_t * cb_10  = NULL;
     evhtp_callback_t * cb_11  = NULL;
@@ -525,30 +537,53 @@ main(int argc, char ** argv) {
     evbase = event_base_new();
     htp    = evhtp_new(evbase, NULL);
 
+    evhtp_set_parser_flags(htp, EVHTP_PARSE_QUERY_FLAG_LENIENT);
     evhtp_set_max_keepalive_requests(htp, max_keepalives);
 
-    cb_1   = evhtp_set_cb(htp, "/ref", test_default_cb, "fjdkls");
-    cb_2   = evhtp_set_cb(htp, "/foo", test_foo_cb, "bar");
-    cb_3   = evhtp_set_cb(htp, "/foo/", test_foo_cb, "bar");
-    cb_4   = evhtp_set_cb(htp, "/bar", test_bar_cb, "baz");
-    cb_5   = evhtp_set_cb(htp, "/500", test_500_cb, "500");
+    /* htp->enable_nodelay = 1; */
+    /* htp->enable_defer_accept = 1; */
+    htp->enable_reuseport = 1;
+
+    cb_1  = evhtp_set_cb(htp, "/ref", test_default_cb, "fjdkls");
+    evhtp_assert(cb_1 != NULL);
+
+    cb_2  = evhtp_set_cb(htp, "/foo", test_foo_cb, "bar");
+    evhtp_assert(cb_2 != NULL);
+
+    cb_3  = evhtp_set_cb(htp, "/foo/", test_foo_cb, "bar");
+    evhtp_assert(cb_3 != NULL);
+
+    cb_4  = evhtp_set_cb(htp, "/bar", test_bar_cb, "baz");
+    evhtp_assert(cb_4 != NULL);
+
+    cb_5  = evhtp_set_cb(htp, "/500", test_500_cb, "500");
+    evhtp_assert(cb_5 != NULL);
+
 #ifndef EVHTP_DISABLE_REGEX
-    cb_6   = evhtp_set_regex_cb(htp, "^(/anything/).*", test_regex, NULL);
+    cb_6  = evhtp_set_regex_cb(htp, "^(/anything/).*", test_regex, NULL);
+    evhtp_assert(cb_6 != NULL);
 #endif
-    cb_7   = evhtp_set_cb(htp, "/pause", test_pause_cb, NULL);
+    cb_7  = evhtp_set_cb(htp, "/pause", test_pause_cb, NULL);
+    evhtp_assert(cb_7 != NULL);
 #ifndef EVHTP_DISABLE_REGEX
-    cb_8   = evhtp_set_regex_cb(htp, "^/create/(.*)", create_callback, NULL);
+    cb_8  = evhtp_set_regex_cb(htp, "^/create/(.*)", create_callback, NULL);
+    evhtp_assert(cb_8 != NULL);
 #endif
-    cb_9   = evhtp_set_glob_cb(htp, "*/glob/*", test_glob_cb, NULL);
-    cb_10  = evhtp_set_cb(htp, "/max_body_size", test_max_body, NULL);
+    cb_9  = evhtp_set_glob_cb(htp, "*/glob/*", test_glob_cb, NULL);
+    evhtp_assert(cb_9 != NULL);
+
+    cb_10 = evhtp_set_cb(htp, "/max_body_size", test_max_body, NULL);
+    evhtp_assert(cb_10 != NULL);
 
     /* set a callback to test out chunking API */
-    cb_11  = evhtp_set_cb(htp, "/chunkme", test_chunking, NULL);
+    cb_11 = evhtp_set_cb(htp, "/chunkme", test_chunking, NULL);
+    evhtp_assert(cb_11 != NULL);
 
     /* set a callback which takes ownership of the underlying bufferevent and
      * just starts echoing things
      */
-    cb_12  = evhtp_set_cb(htp, "/ownme", test_ownership, NULL);
+    cb_12 = evhtp_set_cb(htp, "/ownme", test_ownership, NULL);
+    evhtp_assert(cb_12 != NULL);
 
     /* set a callback to pause on each header for cb_7 */
     evhtp_set_hook(&cb_7->hooks, evhtp_hook_on_path, pause_init_cb, NULL);
@@ -613,7 +648,7 @@ main(int argc, char ** argv) {
     }
 #endif
 
-    if (evhtp_bind_socket(htp, bind_addr, bind_port, 128) < 0) {
+    if (evhtp_bind_socket(htp, bind_addr, bind_port, backlog) < 0) {
         fprintf(stderr, "Could not bind socket: %s\n", strerror(errno));
         exit(-1);
     }
